sqlobject.tests.test_picklecol module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_picklecol module

class `sqlobject.tests.test_picklecol.` `PickleContainer`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = pickle_container
  property `pickledata`
  `q` = pickle_container
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_picklecol.PickleContainer`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'pickle_container'

class `sqlobject.tests.test_picklecol.` `PickleData`

  Bases: `object`

  `pi` = 3.14156

`sqlobject.tests.test_picklecol.` `test_pickleCol`()